@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.23 2004/07/02 12:50:09 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.24 2004/07/04 03:12:42 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -84,7 +84,7 @@ static POOL_STATUS FunctionResultResponse(POOL_CONNECTION *frontend,
 										  POOL_CONNECTION_POOL *backend);
 
 static POOL_STATUS ProcessFrontendResponse(POOL_CONNECTION *frontend, 
-											POOL_CONNECTION_POOL *backend);
+										   POOL_CONNECTION_POOL *backend);
 
 static int synchronize(POOL_CONNECTION *cp);
 static void process_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend);
@@ -246,11 +246,10 @@ POOL_STATUS pool_process_query(POOL_CONNECTION *frontend,
 				if (REPLICATION)
 				{
 					pool_read(SECONDARY(backend), &kind1, 1);
-					if (kind != kind1)
+					if (kind == '\0' || kind != kind1)
 					{
 						pool_error("pool_process_query: kind does not match between backends master(%c) secondary(%c)",
 								   kind, kind1);
-
 						pool_send_error_message(frontend, MAJOR(backend), "XX000", 
 												"kind mismatch between backends", "",
 												"check data consistency between master and secondary", __FILE__, __LINE__);
@@ -284,7 +283,7 @@ POOL_STATUS pool_process_query(POOL_CONNECTION *frontend,
 			{
 				pool_read(SECONDARY(backend), &kind1, 1);
 			}
-			if (kind != kind1)
+			if (kind == '\0' || kind != kind1)
 			{
 				pool_error("pool_process_query: kind does not match between backends master(%c) secondary(%c)",
 						   kind, kind1);
@@ -871,7 +870,7 @@ static POOL_STATUS CursorResponse(POOL_CONNECTION *frontend,
 		if (len != len1)
 		{
 			pool_error("CursorResponse: length does not match between master(%d) and secondary(%d)",
-					 len, len1);
+					   len, len1);
 			pool_error("CursorResponse: master(%s) secondary(%s)", string, string1);
 			return POOL_END;
 		}
@@ -1750,8 +1749,8 @@ POOL_STATUS SimpleForwardToFrontend(char kind, POOL_CONNECTION *frontend, POOL_C
 
 		if (len != len1)
 		{
-			pool_log("SimpleForwardToFrontend: length does not match between backends master(%d) secondary(%d)",
-					   ntohl(len), ntohl(len1));
+			pool_log("SimpleForwardToFrontend: length does not match between backends master(%d) secondary(%d) kind:(%c)",
+					 ntohl(len), ntohl(len1), kind);
 		}
 	}
 
